/***************************************************************************
* File Name: msp430_timer_a.c
* Processor(s): MSP430F16x (tested), MSP430F14x (not tested)
* Compiler: Code Composer Studio V4 (4.2.5.00005)
* 
* Copyright  2013 Playing With Fusion, Inc.
* SOFTWARE LICENSE AGREEMENT: This code is released under the MIT License. 
* 
* Permission is hereby granted, free of charge, to any person obtaining a
* copy of this software and associated documentation files (the "Software"),
* to deal in the Software without restriction, including without limitation
* the rights to use, copy, modify, merge, publish, distribute, sublicense,
* and/or sell copies of the Software, and to permit persons to whom the
* Software is furnished to do so, subject to the following conditions:
* 
* The above copyright notice and this permission notice shall be included in
* all copies or substantial portions of the Software.
* 
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
* FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
* DEALINGS IN THE SOFTWARE.
* **************************************************************************
* REVISION HISTORY:
* Author			Date		Comments
* J. Steinlage		2013Nov30	Original version
* 
* **************************************************************************
* ADDITIONAL NOTES:
* This file contains functions to configure and handle interrputs generated
* by the 'timer A0' module.
***************************************************************************/

#include "msp430x16x.h"
#include "msp430_timer_a.h"

extern unsigned char clk_tick;		// 'tick' used to start next read at set intervals

void Init_TimerA_SysClock(unsigned char mS) // 'mS' value tells fcn at which interval to create a tick 
{
	unsigned int mS_count; 
	
	// code to use DCO as clock source (562.5 kHz)
	if(mS > 116){mS = 116;}						// Max 65535 for register. 563*mS must be below 65535
	mS_count = mS * 563; 						// 563count/562.5kHz = 1ms/interval
	TACTL = TACLR;								// TA Clear	
	TACTL = MC_1 + TASSEL_2 + ID_3;				// up mode (1) + SMCLK + 8x divider
	TACCR0 = (mS_count-1);						// clock * interrupt interval
	TACCTL0 = OUTMOD_1 + CCIE;					// OUTx mode 1 (set) + Cap/Comp Interrupt enable

}

void Stop_TimerA(void)	// Stop timer before changing any of the TimerA registers
{
	TACTL = MC_0;									// Stop TimerA register by setting MCx to 'stop'/0
}

//------------------------------------------------------------------------------
//      TA_ISR    ; TimerA Interrupt Routine
//------------------------------------------------------------------------------

__interrupt void TimerA0_ISR(void);
//TIMERA0_ISR(TimerA0_ISR)
#pragma vector=TIMERA0_VECTOR
__interrupt void TimerA0_ISR(void)
{
	clk_tick = 1;				// set 'tick' to trigger function execution
}
